<?xml version="1.0" encoding="UTF-8"?>      
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<!--
COPYRIGHT NOTICE:
Copyright 2006 Center for Technology in Government.
The Center grants permission to use and modify this software code free of charge provided  
this copyright notice is included. By using this code you agree to indemnify the Center from 
any liability that might arise from its use. Selling the code is expressly forbidden.
-->
<!-- Declare parameters that identifies which chapter to select from xml file -->
<xsl:param name="sub">directions</xsl:param>
<!-- Main Template: Match moderate_xml.xml file document root node, called "book" into html page tags -->
<xsl:template match="book">
<!-- Print DOCTYPE declaration at top of HTML document  -->	
<xsl:text disable-output-escaping="yes">
	<![CDATA[
		<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" 
		     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
	]]>
</xsl:text>	
<html xmlns="http://www.w3.org/1999/xhtml" lang="en-US">
<!-- Set the Browser title, get exernal css stylesheet  --> 
 <head> 
  <title><xsl:value-of select="@label"/>: <xsl:value-of select="$sub"/></title>
   <style type="text/css">
   <xsl:comment>
    h1 { color: #000000; font-weight: bold; font-size: 1em; font-family: Arial, Helvetica, Geneva, Swiss, sans-serif;  text-transform: none; } 
    p {color: #000; font-size: .85em; font-family: Arial, Helvetica, Geneva, Swiss, sans-serif; }
    h1.menu { color: #800000; font-weight: bold; font-size: .9em; font-family: Arial, Helvetica, Geneva, Swiss, sans-serif;  text-transform: none; }
    #left_themes  {position: absolute;width: 125px;	top: 20px;left: 15px;padding-right: 10px;margin: 0px;background-image: url(../img/common/dotted.gif);background-repeat: repeat-y;	background-position: top right;}
    div.main {position: absolute;width: 480px;top: 20px;left: 160px;padding-left: 15px;	padding-right: 5px;	padding-top: 0px;padding-bottom: 5px;	margin: 0px;}
    .lftmenu { color: #354283; font-weight: normal; font-size: .75em; font-family: Arial, Helvetica, Geneva, Swiss, sans-serif; }
    .lftmenublack { color: #000000; font-weight: normal; font-size: .75em; font-family: Arial, Helvetica, Geneva, Swiss, sans-serif; }
   </xsl:comment>
   </style>
 </head>
<!-- Create the Main Body of the HTML page  -->
 <body>
<!-- Create left navigation bar from chapter titles in moderate_xml.xml file using cascading style sheet and xsl -->
 <div id="left_themes">
  <h1 class="menu">
   <xsl:value-of select="title"/>       
  </h1>
  <!-- xsl:for-each reads through each chapter in xml file and selects the title for a menu item-->
   <xsl:for-each select="chapter">
    <xsl:variable name="label"><xsl:value-of select="@label"/></xsl:variable>
  <!-- compares chapter label attribute to sub parameter to determine if link should be inserted -->
    <xsl:choose>												
     <xsl:when test="@label=$sub">
      <span class="lftmenublack">
       <xsl:value-of select="title"/>
      </span>
     </xsl:when>	
     <xsl:otherwise>
      <span class="lftmenublack">
       <a href="about?sub={$label}">
        <xsl:value-of select="title"/>
       </a>	
      </span>				
     </xsl:otherwise>
    </xsl:choose>		
    <br /><br />
   </xsl:for-each>
 </div>			
<!-- START Main Content Section -->
 <div class="main">
 <!-- Selects only chapter that matches the sub parameters, in this case "mission" -->						
  <xsl:for-each select="chapter[@label=$sub]">
    <h1><xsl:apply-templates select="title"/></h1>
     <xsl:for-each select="para">
      <p><xsl:apply-templates select="."/></p>
     </xsl:for-each>
   </xsl:for-each>
 </div>
<!-- END Main Content Section -->
 </body>
</html>
</xsl:template>
<!-- END Main Template -->

<xsl:template match="title">
 <xsl:value-of select="."/>
</xsl:template>
	
<xsl:template match="para">
 <xsl:apply-templates/>
</xsl:template>
	
<xsl:template match="emphasis">
 <strong>
   <xsl:apply-templates/>
 </strong>
</xsl:template>
	
<xsl:template match="ulink">
 <xsl:variable name="ref">
  <xsl:value-of select="@url"/>
 </xsl:variable>
 <a href="{$ref}" accesskey="" tabindex="0"><xsl:apply-templates/></a>
</xsl:template>
	
<xsl:template match="strong|br">
 <xsl:copy>
  <xsl:apply-templates/>
 </xsl:copy>
</xsl:template>	
	
</xsl:stylesheet>



